summaryrefslogtreecommitdiff
path: root/novaclient/v2/cells.py
diff options
context:
space:
mode:
Diffstat (limited to 'novaclient/v2/cells.py')
-rw-r--r--novaclient/v2/cells.py16
1 files changed, 14 insertions, 2 deletions
diff --git a/novaclient/v2/cells.py b/novaclient/v2/cells.py
index e6a16667..44cadddb 100644
--- a/novaclient/v2/cells.py
+++ b/novaclient/v2/cells.py
@@ -13,32 +13,44 @@
# License for the specific language governing permissions and limitations
# under the License.
+import warnings
+
from novaclient import base
+from novaclient.i18n import _
+
+CELL_V1_DEPRECATION_WARNING = _(
+ 'The cells v1 interface has been deprecated in Nova since 16.0.0 Pike '
+ 'Release. This API binding will be removed in the first major release '
+ 'after the Nova server 20.0.0 Train release.')
class Cell(base.Resource):
+ """DEPRECATED"""
def __repr__(self):
return "<Cell: %s>" % self.name
class CellsManager(base.Manager):
+ """DEPRECATED"""
resource_class = Cell
def get(self, cell_name):
"""
- Get a cell.
+ DEPRECATED Get a cell.
:param cell_name: Name of the :class:`Cell` to get.
:rtype: :class:`Cell`
"""
+ warnings.warn(CELL_V1_DEPRECATION_WARNING, DeprecationWarning)
return self._get("/os-cells/%s" % cell_name, "cell")
def capacities(self, cell_name=None):
"""
Get capacities for a cell.
:param cell_name: Name of the :class:`Cell` to get capacities for.
:rtype: :class:`Cell`
"""
+ warnings.warn(CELL_V1_DEPRECATION_WARNING, DeprecationWarning)
path = ["%s/capacities" % cell_name, "capacities"][cell_name is None]
return self._get("/os-cells/%s" % path, "cell")
@@ -13,32 +13,44 @@
def capacities(self, cell_name=None):
"""
- Get capacities for a cell.
+ DEPRECATED Get capacities for a cell.
:param cell_name: Name of the :class:`Cell` to get capacities for.
:rtype: :class:`Cell`